/**
 * DEVHELP32.H - DevHelp header file for 32 bit Watcom-based device drivers
 *
 * Copyright (c) 2013 David Azarewicz david@88watts.net
 *
 * The following source code is provided to you solely for the purpose of
 * assisting you in developing your own eCS device drivers. You may use
 * this software in your device drivers free of charge.
 */
#ifndef DEVHELP_INCLUDED
#define DEVHELP_INCLUDED

#ifdef __WATCOMC__

#ifndef OS2_INCLUDED
#define INCL_NOPMAPI
#include <os2.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define DHGETDOSV_SYSINFOSEG       1
#define DHGETDOSV_LOCINFOSEG       2
#define DHGETDOSV_VECTORSDF        4
#define DHGETDOSV_VECTORREBOOT     5
#define DHGETDOSV_YIELDFLAG        7
#define DHGETDOSV_TCYIELDFLAG      8
#define DHGETDOSV_DOSCODEPAGE      11
#define DHGETDOSV_INTERRUPTLEV     13
#define DHGETDOSV_DEVICECLASSTABLE 14
#define DHGETDOSV_DMQSSELECTOR     15
#define DHGETDOSV_APMINFO          16

extern ULONG __syscall Dev32Help_GetDOSVar(USHORT VarNumber, USHORT VarMember, VOID **KernalVar);

extern void Dev32Help_EOI(ULONG Irq);
#pragma aux Dev32Help_EOI parm [ecx] modify nomemory [eax ecx edx];

extern ULONG __syscall Dev32Help_SetIRQ(void *HandlerOffset, USHORT IRQ, UCHAR SharableFlag);

extern ULONG Dev32Help_AllocGDTSelector(USHORT *pSelectors, ULONG Count);
#pragma aux Dev32Help_AllocGDTSelector parm [eax] [ecx] value [eax] modify nomemory [eax ecx edx];

extern ULONG Dev32Help_LinToGDTSelector(USHORT Selector, ULONG LinearAddr, ULONG Size);
#pragma aux Dev32Help_LinToGDTSelector parm [eax] [ebx] [ecx] value [eax] modify nomemory [eax ecx edx];

extern ULONG Dev32Help_PhysToGDTSel(ULONG PhysAddr, ULONG Count, USHORT Selector, UCHAR Access);
#pragma aux Dev32Help_PhysToGDTSel parm [eax] [ecx] [esi] [edx] value [eax] modify nomemory [eax ecx edx];

/* This function can be called at interrupt time */
extern ULONG Dev32Help_PhysToLin(ULONG PhysAddr, ULONG ulSize, VOID **pLinAdr);
#pragma aux Dev32Help_PhysToLin parm [esi] [ecx] [edi] value [eax] modify nomemory [eax ecx edx];

/* Finds the specified Device Driver and returns the data necessary to access it. */
extern ULONG __syscall Dev32Help_FindDD(char *DevName, DDINFO *DDinfo);

/* Calles the specified Device Driver's strategy routine with the given request packet */
extern ULONG __syscall Dev32Help_CallStrategy(DDINFO *DDinfo, void *pkt);

/* Calles the specified Device Driver's IDC routine with the given request packet */
extern ULONG __syscall Dev32Help_CallIdc(DDINFO *DdInfo, void *Packet);

/* Sends an IOCtl request to the specified device driver */
extern ULONG __syscall Dev32Help_IOCtl(DDINFO *pDdInfo, UCHAR Category, UCHAR Function, void *pvParam, ULONG ulParamLen, void *pvData, ULONG ulDataLen);

extern ULONG Dev32Help_FileIO(ULONG Function, void *FileInfo);
#pragma aux Dev32Help_FileIO parm [edx] [eax] value [eax] modify nomemory [eax ecx edx];

extern ULONG __syscall Dev32Help_FileOpen(char *pFileName, ULONG *pFileLen);

#ifdef __cplusplus
}
#endif

#endif
#endif
